#!/bin/bash
#Faraday Util Script
#Fatih USTA <fatihusta@labrisnetworks.com>

#Create initial database and tables
#Create Super user
#Change Password

prog=$(/usr/bin/basename $0)
action=$1

faradaydir=/usr/share/faraday/server/

_python=/usr/share/faraday/server/env/bin/python2.7
_manage=/usr/share/faraday/server/manage.py
_su=/bin/su

if [[ $action == 'initdb' ]];then

    # sql to check whether given database exist
    db_exists=$($_su postgres -c "psql --dbname=postgres -t -c \"select count(1) from pg_catalog.pg_database where datname = 'faraday'\" 2>/dev/null | tr -d ' '| tr -d '\n'")

    if [ $db_exists -eq 0 ] ; then
        cd $faradaydir &>/dev/null

        $_python $_manage initdb

        cd - &>/dev/null
    else
        echo "Database already exists."
	exit 0
    fi

elif [[ $action == 'createsuperuser' ]]; then

    shift
    params="$@"

    if [ -z "$params" ]; then
        params="--help"
    fi

    # sql to check whether given database exist
    db_exists=$($_su postgres -c "psql --dbname=postgres -t -c \"select count(1) from pg_catalog.pg_database where datname = 'faraday'\" 2>/dev/null | tr -d ' '| tr -d '\n'")
    
    if [ $db_exists -eq 0 ] ; then
        echo "Please first create database."
        exit 1
    fi

    $_python $_manage createsuperuser $params 2>/dev/null

    if [ $? != 0 ]; then
        echo "User already exists."
    fi

elif [[ $action == 'changepassword' ]]; then

    shift
    params="$@"

    if [ -z "$params" ]; then
        params="--help"
    fi

    # sql to check whether given database exist
    db_exists=$($_su postgres -c "psql --dbname=postgres -t -c \"select count(1) from pg_catalog.pg_database where datname = 'faraday'\" 2>/dev/null | tr -d ' '| tr -d '\n'")
    
    if [ $db_exists -eq 0 ] ; then
        echo "Please first create database."
        exit 1
    fi

    $_python $_manage change-password $params 2>/dev/null

    if [ $? != 0 ]; then
        echo "Failed"
    fi
else

cat <<EOF
Usage:
    $prog [COMMAND]

COMMAND:
    initdb                                | Create initial postgresql database and tables
    createsuperuser [OPTIONS]             | Create faraday superuser
    changepassword  [OPTIONS]             | Change Password (--username --password)

OPTIONS:
    --username      <username>            | Faraday username
    --email         <email@domain.com>    | Email address
    --password      <P@sW0rD>             | Password
EOF

fi

exit 0
